@@ -2,24 +2,24 @@ import os
 import subprocess
 import shutil
 
-def hello_world():
+def helloWorld():
     string = 'Hello, World!'
     print(string)
 
 
-def print_no_newline(*args):
+def printNoNewline(*args):
     for arg in args:
         print(arg, end=" ")
 
 
 def clearPycache(path):
-    if not shutil.rmtree(os.path.join(path, "__pycache__")):
-        return False
-    else:
+    if shutil.rmtree(os.path.join(path, "__pycache__")):
         return True
+    else:
+        return False
 
 
-def install_modules(*args):
+def installModules(*args):
     for module in args:
         command = "python -m pip install {}".format(module)
         if subprocess.run(command):
